<?php
/**
 * Tokimeki functions and definitions
 *
 * @package Tokimeki
 */

require_once get_template_directory() . '/inc/customizer.php';
require_once get_template_directory() . '/inc/widgets/recent-post-widget.php';


if ( ! function_exists( 'tokimeki_setup' ) ) {
	/**
	 * Theme sets up.
	 */
	function tokimeki_setup() {
		load_theme_textdomain( 'tokimeki', get_template_directory() . '/languages' );

		add_theme_support( 'automatic-feed-links' );

		register_nav_menus( array(
			'primary-menu' => esc_html__( 'Header navigation menu', 'tokimeki' ),
			'social-links' => esc_html__( 'Header social links', 'tokimeki' ),
		) );

		add_theme_support( 'title-tag' );
		add_theme_support( 'post-thumbnails' );

		$header_picture = array( 'flex-width' => true, 'uploads' => true, 'header-text' => false );
		add_theme_support( 'custom-header', $header_picture );

		add_theme_support( 'custom-logo' );

		$html5support = array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		);
		add_theme_support( 'html5', $html5support );

		add_editor_style( 'asset/css/editor-style.css' );
	}
}
add_action( 'after_setup_theme', 'tokimeki_setup' );

/**
 * Set up $content_width.
 */
function tokimeki_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'tokimeki_content_width', 820 );
}
add_action( 'after_setup_theme', 'tokimeki_content_width', 0 );

/**
 * Loading styles and scripts.
 */
function tokimeki_styles_load() {
	wp_enqueue_style( 'tokimeki', get_stylesheet_directory_uri() . '/asset/css/style.min.css', array(), null, 'all' );

	wp_enqueue_script( 'foundation', get_template_directory_uri() . '/asset/js/foundation.min.js', array( 'jquery' ), null, true );
	wp_enqueue_script( 'moment', get_template_directory_uri() . '/asset/js/moment-with-locales.min.js', array( 'jquery' ), null, true );

	wp_enqueue_script( 'tokimeki-script', get_template_directory_uri() . '/asset/js/script.js', array( 'jquery' ), null, true );
	wp_localize_script( 'tokimeki-script', 'wplocale', array( 'momentlocale' => esc_html__( 'en', 'tokimeki' ) ) );

	if ( is_singular() ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'tokimeki_styles_load' );

/**
 * Register sidebar.
 */
function tokimeki_sidebar_init() {
	register_sidebar( array(
		'name' => esc_html__( 'sidebar', 'tokimeki' ),
		'id' => 'sidebar-1',
		'description' => esc_html__( 'Sidebar widget area', 'tokimeki' ),
		'before_widget' => '<div id="%1$s" class="sidebar-widgetarea widget %2$s">',
		'after_widget' => '</div>',
	) );

	register_sidebar( array(
		'name' => esc_html__( 'footer', 'tokimeki' ),
		'id' => 'sidebar-footer-1',
		'description' => esc_html__( 'Footer widget area', 'tokimeki' ),
		'before_widget' => '<div id="%1$s" class="sidebar-widgetarea widget %2$s">',
		'after_widget' => '</div>',
	) );
}
add_action( 'widgets_init', 'tokimeki_sidebar_init' );

/**
 * Register widgets.
 */
function tokimeki_widget_register() {
	register_widget( 'Tokimeki_Recent_Posts' );
}
add_action( 'widgets_init', 'tokimeki_widget_register' );

/**
 * If user sets showing sticky posts at top-post area, main loop ignore sticky posts.
 */
function tokimeki_home_query_pre( $query ) {
	if ( get_theme_mod( 'top_post_sortby' ) ) {
		if ( 'sticky' === get_theme_mod( 'top_post_sortby' ) ) {
			if ( $query->is_home() && $query->is_main_query() ) {
				$query->set( 'ignore_sticky_posts', 1 );
			}
		}
	}
}
add_action( 'pre_get_posts', 'tokimeki_home_query_pre' );

if ( ! function_exists( 'tokimeki_comment_format' ) ) {
	/**
	 * Comment callback.
	 */
	function tokimeki_comment_format( $comment, $args, $depth ) {
		$GLOBALS['comment'] = $comment;

		switch ( $comment->comment_type ) {
			case 'pingback' :
			case 'trackback' : ?>
				<li class="post pingback">
				<p class="pingback__content"><i class="fa fa-thumb-tack pingback__icon" aria-hidden="true"></i><?php comment_author_link(); ?><?php edit_comment_link( esc_html__( 'Edit', 'tokimeki' ) ); ?></p><?php
				break;
			default : ?>
			<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
				<div id="comment-<?php comment_ID(); ?>" class="comment comment-container">
					<div class="comment__avatar">
						<?php echo get_avatar( $comment, 60 ); ?>
					</div>
					<div class="comment__content">
						<div class="comment__meta">
							<?php printf( wp_kses( __( '<cite class="fn">%s</cite>', 'tokimeki' ), array( 'cite' => array( 'class' => array() ) ) ), get_comment_author_link() ); ?>
							<?php echo '<time datetime="' . esc_attr( get_comment_date( 'Y-m-d' ) ) . '">' . esc_html( get_comment_date() ) . '</time>'; ?>
							<?php if ( get_queried_object()->post_author === $comment->user_id ) { ?>
								<span class="label"><?php esc_html_e( 'Author', 'tokimeki' ); ?></span>
							<?php } ?>
							<div class="comment__reply">
								<?php comment_reply_link( array_merge( $args, array( 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
								<?php edit_comment_link( esc_html__( 'Edit', 'tokimeki' ) ); ?>
							</div>
						</div>
						<?php if ( '0' === $comment->comment_approved ) : ?>
							<div class="comment__moderation">
								<em><?php esc_html_e( 'Your comment is awaiting moderation.', 'tokimeki' ); ?></em>
							</div>
						<?php endif; ?>
						<div class="comment__text"><?php comment_text(); ?></div>
					</div>
				</div>
				<?php
				break;
		}
	}
}
